<?php
/*
Plugin Name: RandImage
Plugin URI: http://meandmymac.net/plugins/randimage/
Description: Allows to show random images from the WordPress media library.
Author: Arnan de Gans
Version: 0.4
Author URI: http://meandmymac.net
*/ 

randimage_check_config();
add_action('admin_menu', 'randimage_add_pages'); //Add page menu links
add_action('widgets_init', 'randimage_widget_init'); //Initialize the widget

if(isset($_POST['randimage_submit_options']) AND $_GET['updated'] == "true") {
	add_action('init', 'randimage_options_submit'); //Update Options
}

function randimage_add_pages() {
	add_options_page('RandImage', 'RandImage', 10, basename(__FILE__), 'randimage_options_page');
}
$randimage_config = get_option('randimage_config'); // Load Options

/*-------------------------------------------------------------
 Name:      randimage_options_page

 Purpose:   Admin options page
 Receive:   -none-
 Return:    -none-
-------------------------------------------------------------*/
function randimage_options_page() {
	$randimage_config = get_option('randimage_config');
?>
	<div class="wrap">
	  	<h2>RandImage options</h2>
	  	<form method="post" action="<?php echo $_SERVER['REQUEST_URI'];?>&amp;updated=true">
	    	<input type="hidden" name="randimage_submit_options" value="true" />

	    	<table class="form-table">

		      	<tr valign="top">
			        <th scope="row">How much photos in sidebar?</th>
			        <td><input name="randimage_amount" type="text" value="<?php echo stripslashes($randimage_config['amount']);?>" size="3" /> <em>(default: 2)</em></td>
		      	</tr>
		      	<tr valign="top">
			        <th scope="row">Link picture to ...</th>
			        <td><select name="randimage_linkto">
						<?php if($randimage_config['linkto'] == "image") { ?>
						<option value="image">gallery image</option>
						<option value="post">post</option>
						<?php } else { ?>
						<option value="post">post</option>
						<option value="image">gallery image</option>
						<?php } ?>
					</select></td>
		      	</tr>
		      	<tr valign="top">
			        <th scope="row">HTML before</th>
			        <td><input name="randimage_before" type="text" value="<?php echo stripslashes($randimage_config['before']);?>" size="20" /> <em>(default: &lt;li&gt;)</em></td>
		      	</tr>
		      	<tr valign="top">
			        <th scope="row">Spacer</th>
			        <td><input name="randimage_spacer" type="text" value="<?php echo stripslashes($randimage_config['spacer']);?>" size="20" /> <em>(default: &lt;/li&gt;&lt;li&gt;)</em></td>
		      	</tr>
		      	<tr valign="top">
			        <th scope="row">HTML behind</th>
			        <td><input name="randimage_behind" type="text" value="<?php echo stripslashes($randimage_config['behind']);?>" size="20" /> <em>(default: &lt;/li&gt;)</em></td>
		      	</tr>

	    	</table>
		    <p class="submit">
		      	<input type="submit" name="Submit" value="Update Options &raquo;" />
		    </p>
		</form>
	</div>
<?php
}	

/*-------------------------------------------------------------
 Name:      randimage_sidebar

 Purpose:   Fetch and show random images from the WP media lib
 Receive:   -none-
 Return:    -none-
-------------------------------------------------------------*/
function randimage_sidebar() {
	global $wpdb, $randimage_config;
		
	$SQL = "SELECT ID, post_parent FROM ".$wpdb->prefix."posts 
		WHERE post_type = 'attachment' 
		AND (post_mime_type = 'image/jpeg' OR post_mime_type = 'image/gif' OR 
		post_mime_type = 'image/png' OR post_mime_type = 'image/bmp' OR 
		post_mime_type = 'image/tiff' OR post_mime_type = 'image/x-icon')
		ORDER BY rand() LIMIT ".$randimage_config['amount'];

	$thumbs = $wpdb->get_results($SQL);

	$output = '';
	$output .= $randimage_config['before'];
	foreach($thumbs as $thumb) {
		if($randimage_config['linkto'] == "image") {
			$linkto = get_permalink($thumb->ID);
		} else {
			$SQL2 = "SELECT ID from ".$wpdb->prefix."posts
				WHERE ID = ".$thumb->post_parent." LIMIT 1";
			$temp_id = $wpdb->get_row($SQL2);
			$linkto = get_permalink($temp_id->ID);
		}
		
		$image = wp_get_attachment_image_src($thumb->ID, 'thumbnail', false);
		if($image) {
			list($src, $width, $height) = $image;
			$hwstring = image_hwstring($width, $height);
			if(is_array($size))
				$size = join('x', $size);
			$output .= '<a href="'.$linkto.'" alt=""><img src="'.attribute_escape($src).'" '.$hwstring.'class="attachment-'.attribute_escape($size).'" alt="" /></a>';
			$output .= $randimage_config['spacer'];
		}
	}
	$output .= $randimage_config['behind'];
	
	echo stripslashes(html_entity_decode($output));
}

/*-------------------------------------------------------------
 Name:      randimage_widget_init

 Purpose:   RandImage widget for the sidebar
 Receive:   -none-
 Return:    -none-
-------------------------------------------------------------*/
function randimage_widget_init() {

	if ( !function_exists('register_sidebar_widget') )
		return;
	if ( !function_exists('randimage_sidebar') )
		return;

	function randimage_widget($args) {
		extract($args);

		echo $before_widget . $before_title . $after_title;
		$url_parts = parse_url(get_bloginfo('home'));
		randimage_sidebar();
		echo $after_widget;
	}

	$widget_ops = array('classname' => 'randimage_widget', 'description' => "Options are found on the 'settings > RandImage' panel!" );
	wp_register_sidebar_widget('RandImage', 'RandImage', 'randimage_widget', $widget_ops);
}

/*-------------------------------------------------------------
 Name:      randimage_check_config

 Purpose:   Create or update the options
 Receive:   -none-
 Return:    -none-
-------------------------------------------------------------*/
function randimage_check_config() {
	if ( !$option = get_option('randimage_config') ) {
		// Default Options
		$option['amount'] 					= 2;
		$option['before'] 					= '<li>';
		$option['spacer']					= '</li><li>';
		$option['behind'] 					= '</li>';
		$option['linkto'] 					= 'image';
		update_option('randimage_config', $option);
	}
}

/*-------------------------------------------------------------
 Name:      randimage_options_submit

 Purpose:   Save options
 Receive:   $_POST
 Return:    -none-
-------------------------------------------------------------*/
function randimage_options_submit() {
	//options page
	$option['amount'] 				= trim($_POST['randimage_amount'], "\t\n ");
	$option['before'] 				= htmlspecialchars(trim($_POST['randimage_before'], "\t\n "), ENT_QUOTES);
	$option['spacer'] 				= htmlspecialchars(trim($_POST['randimage_spacer'], "\t\n "), ENT_QUOTES);
	$option['behind'] 				= htmlspecialchars(trim($_POST['randimage_behind'], "\t\n "), ENT_QUOTES);
	$option['linkto'] 				= trim($_POST['randimage_linkto'], "\t\n ");
	update_option('randimage_config', $option);
}
?>